# Copyright 2020 Cloudbase Solutions Srl
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import json
import yaml


class YamlParserConfigError(Exception):
    """Exception for Yaml parsing failures"""
    pass


def parse_json_yaml(raw_data):
    """Parse data as json. Fallback to yaml if json parsing fails"""

    try:
        return json.loads(raw_data)
    except (TypeError, ValueError, AttributeError,
            json.decoder.JSONDecodeError):
        loader = getattr(yaml, 'CLoader', yaml.Loader)
        try:
            return yaml.load(raw_data, Loader=loader)
        except (TypeError, ValueError, AttributeError,
                yaml.parser.ParserError, yaml.scanner.ScannerError):
            raise YamlParserConfigError("Invalid yaml data provided.")
